@@ -28,7 +28,9 @@ static int lockCount=0;
 static int active=1;
 
 static void connectToDbusVibra();
+static void connectToDbusProfile();
 static void readConfig();
+static void getProfileState();
 
 static std::string openSound;
 static std::string closeSound;
@@ -41,6 +43,7 @@ static std::string lv;
 static std::string ks;
 static std::string ls;
 
+static int silent=0;
 
 time_t keyboardSlide;
 
@@ -74,13 +77,19 @@ int main(int argc, char *argv[])
 	
 	GMainLoop *loop;
 	DBusConnection *bus;
+	DBusConnection *busSession;
 	DBusError error;
 
 	loop = g_main_loop_new (NULL, FALSE);
 	dbus_error_init (&error);
 	bus = dbus_bus_get (DBUS_BUS_SYSTEM, &error);
+	busSession = dbus_bus_get (DBUS_BUS_SESSION, &error);
 
+	
 	connectToDbusVibra();
+	connectToDbusProfile();
+	
+	getProfileState();
 	
 	if (!bus) 
 	{
@@ -90,6 +99,7 @@ int main(int argc, char *argv[])
 	}
 	
 	dbus_connection_setup_with_g_main (bus, NULL);
+	dbus_connection_setup_with_g_main (busSession, NULL);
 
 	dbus_bus_add_match (bus, "type='signal',interface='com.nokia.mce.signal'",&error);
 
@@ -97,7 +107,10 @@ int main(int argc, char *argv[])
 	
 	dbus_bus_add_match (bus, "type='signal',interface='org.freedesktop.Hal.Device'",&error);
 
+	dbus_bus_add_match (busSession, "type='signal',interface='com.nokia.profiled'",&error);
+	
 	dbus_connection_add_filter (bus, signal_filter, loop, NULL);											
+	dbus_connection_add_filter (busSession, signal_filter, loop, NULL);											
 	g_main_loop_run (loop);												      
 
 return 0;
@@ -114,6 +127,42 @@ static DBusPendingCall* pendingVib;
 static int retVib;
 static const char* paramVib;
 															
+static int connectedProf;
+static DBusMessage* msgProf;
+static DBusMessageIter argsProf;
+static DBusConnection* connProf;
+static DBusError errProf;
+static DBusPendingCall* pendingProf;
+static int retProf;
+static const char* paramProf;
+
+static void connectToDbusProfile()
+{
+
+       	dbus_error_init(&errProf);
+      	connProf = dbus_bus_get_private(DBUS_BUS_SESSION, &errProf);
+	if (dbus_error_is_set(&errProf))
+	{
+		dbus_error_free(&errProf);
+	}
+	if (NULL == connProf)
+	{
+		return;
+	}
+	
+	retProf = dbus_bus_request_name(connProf, "lockdaemon.profile", DBUS_NAME_FLAG_REPLACE_EXISTING , &errProf);
+
+	if (dbus_error_is_set(&errProf))
+	{
+		dbus_error_free(&errProf);
+	}
+	if (DBUS_REQUEST_NAME_REPLY_PRIMARY_OWNER != retProf)
+	{
+		return;
+	}
+	connectedProf=1;
+
+}
 
 
 static void connectToDbusVibra()
@@ -146,6 +195,73 @@ static void connectToDbusVibra()
 }
 
 
+static void getProfileState()
+{
+
+	std::cout<<"getting profile state"<<std::endl;
+
+	char* reply;
+
+        msgProf = dbus_message_new_method_call("com.nokia.profiled",                                  
+			"/com/nokia/profiled",
+			"com.nokia.profiled",
+			"get_profile");
+
+   if (NULL == msgProf)
+        {
+                return;
+        }
+
+
+   dbus_message_iter_init_append(msgProf, &argsProf);
+
+        if (!dbus_connection_send_with_reply (connProf, msgProf, &pendingProf, -1))
+        {
+                return;
+        }
+        if (NULL == pendingProf)
+        {
+                return;
+        }
+
+        dbus_connection_flush(connProf);
+
+	g_print("Waiting for state\n");
+	
+        dbus_message_unref(msgProf);
+
+	dbus_pending_call_block(pendingProf);
+
+	msgProf=dbus_pending_call_steal_reply(pendingProf);
+
+	if (NULL==msgProf)
+	{
+		g_print("Null reply \n");
+		return;
+	}
+
+	dbus_pending_call_unref(pendingProf);
+
+	dbus_message_iter_init(msgProf,&argsProf);
+	
+	if (DBUS_TYPE_STRING == dbus_message_iter_get_arg_type(&argsProf))
+	{
+		g_print("getting argument: ");
+		dbus_message_iter_get_basic(&argsProf,&reply);
+		g_print("%s",reply);
+		if (reply[0]=='g')
+		{
+			silent=0;
+		}
+		else 
+			silent=1;
+	}
+
+	dbus_message_unref(msgProf);
+	
+
+}
+
 
 static void vibrate(int type)
 {
@@ -201,10 +317,6 @@ static void vibrate(int type)
         dbus_connection_flush(connVib);
         dbus_message_unref(msgVib);
 
-
-
-
-
 }
 
 
@@ -271,7 +383,7 @@ static DBusHandlerResult signal_filter (DBusConnection *connection, DBusMessage
 						keyboardSlide=time(NULL);
 						if (readKeyboardState())
 						{
-							if (ks.compare("1")==0)
+							if (ks.compare("1")==0 && !silent)
 							{
 								musicOff->stop();
 								musicOn->play();
@@ -283,7 +395,7 @@ static DBusHandlerResult signal_filter (DBusConnection *connection, DBusMessage
 						else
 						{
 							
-							if (ks.compare("1")==0)
+							if (ks.compare("1")==0 && !silent)
 							{
 								musicOn->stop();
 								musicOff->play();
@@ -320,7 +432,7 @@ static DBusHandlerResult signal_filter (DBusConnection *connection, DBusMessage
 			if (s[0]=='l' && lockCount==0)
 			{
 	
-				if (ls.compare("1")==0)
+				if (ls.compare("1")==0 && !silent)
 				{		
 					musicOnLock->stop();
 					musicOffLock->play();
@@ -333,7 +445,7 @@ static DBusHandlerResult signal_filter (DBusConnection *connection, DBusMessage
 			else if (s[0]=='u')
 			{
 			
-				if (ls.compare("1")==0)
+				if (ls.compare("1")==0 && !silent)
 				{
 					musicOffLock->stop();
 					musicOnLock->play();
@@ -347,6 +459,34 @@ static DBusHandlerResult signal_filter (DBusConnection *connection, DBusMessage
 		}
 		return DBUS_HANDLER_RESULT_HANDLED;
 	}
+	//profile changed message
+	else if (dbus_message_is_signal (message, "com.nokia.profiled", "profile_changed")) 
+	{
+	  	DBusError error;
+		bool a,b;
+  		char *s;
+		dbus_error_init (&error);
+		
+		g_print("Profile changed:\n");
+		
+		if (dbus_message_get_args(message, &error, DBUS_TYPE_BOOLEAN, &a, DBUS_TYPE_BOOLEAN, &b, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID) && active) 
+		{
+			g_print(s);
+			if (s[0]=='g')
+			{
+				g_print(" I can talk!\n");
+				silent=0;
+			}
+			else
+			{
+				g_print(" Silent I shall be!\n");
+				silent=1;
+
+			}
+		}
+		
+		return DBUS_HANDLER_RESULT_HANDLED;
+	}
 
 	//Silence message	
 	else if (dbus_message_is_signal (message, "hopbeat.lockDaemon", "Switch")) 
